@@ -71,6 +71,7 @@ LoggerLevel = Literal["error", "warn", "info", "debug", "trace", "attention", "s
 APIEventType = Literal["finishLaunching", "shutdown"]
 PTZMovementType = Literal["absolute", "relative", "continuous", "home", "preset", "stop"]
 RTSPAudioCodec = Literal["aac", "opus", "pcma"]
+ProbeAudioCodec = Literal["aac", "opus", "pcma"]
 
 # Basic types
 Callback = Union[
@@ -189,9 +190,9 @@ class VideoStreamInfo(TypedDict):
 
 
 class ProbeConfig(TypedDict, total=False):
-    video: Union[Literal["all"], list[VideoCodec]]
-    audio: Union[Literal["all"], list[AudioCodec]]
-    microphone: Union[Literal["all"], list[AudioCodec]]
+    video: bool
+    audio: Union[Literal["all"], list[ProbeAudioCodec]]
+    microphone: bool
 
 
 class ProbeStream(TypedDict):
